@@ -16,7 +16,7 @@
  */
 
 #define _FILE_OFFSET_BITS 64
-#define VERSION "dmg2img v1.6.1 is derived from dmg2iso by vu1tur (to@vu1tur.eu.org)"
+#define VERSION "dmg2img v1.6.2 is derived from dmg2iso by vu1tur (to@vu1tur.eu.org)"
 #define USAGE "\
 Usage: dmg2img [-s] [-v] [-V] [-d] <input.dmg> [<output.img>]\n\
 or     dmg2img [-s] [-v] [-V] [-d] -i <input.dmg> -o <output.img>\n\n\
@@ -395,6 +395,7 @@ int main(int argc, char *argv[])
 					(unsigned long long)in_size,
 					sztype
 					);
+				fflush(FDBG);
 				bi++;
 			}
 			if (verbose >= 3)
@@ -556,8 +557,8 @@ int main(int argc, char *argv[])
 					       (unsigned long long)out_offs,
 					       (unsigned long long)out_size, reserved);
 			} else if (block_type == BT_TERM) {
-				if (in_offs == 0 && partnum > 0) {
-					if (convert_char8((unsigned char *)parts[1].Data + 24) != 0)
+				if (in_offs == 0 && partnum > i+1) {
+					if (convert_char8((unsigned char *)parts[i+1].Data + 24) != 0)
 						in_offs_add = 0;
 				} else
 					in_offs_add = 0;
